/*!
 *  @file    lib.c
 *  @author  HiSEON (ikseon@nepirity.com)
 *
 *  @internal
 *       Created:  2018년 03월 22일
 *     Copyright:  Copyright (c) 2018, HiSEON
 */

#include <stdio.h>
#include "src/lib.h"
